diff src/cmds.c @ 109684:dbc0119ac80e

Make some doc strings bidi-friendly. cmds.c (Fforward_line, Fbeginning_of_line, Fend_of_line): editfns.c (Fline_beginning_position, Fline_end_position): State in the doc strings that start and end of line are in the logical order.
author Eli Zaretskii <eliz@gnu.org>
date Sun, 08 Aug 2010 19:43:26 +0300
parents 228a5fa4eda0
children 3db1493a6f89
line wrap: on
line diff
--- a/src/cmds.c	Sun Aug 08 19:23:11 2010 +0300
+++ b/src/cmds.c	Sun Aug 08 19:43:26 2010 +0300
@@ -113,7 +113,8 @@
 
 DEFUN ("forward-line", Fforward_line, Sforward_line, 0, 1, "^p",
        doc: /* Move N lines forward (backward if N is negative).
-Precisely, if point is on line I, move to the start of line I + N.
+Precisely, if point is on line I, move to the start of line I + N
+\("start of line" in the logical order).
 If there isn't room, go as far as possible (no error).
 Returns the count of lines left to move.  If moving forward,
 that is N - number of lines moved; if backward, N + number moved.
@@ -157,7 +158,7 @@
 }
 
 DEFUN ("beginning-of-line", Fbeginning_of_line, Sbeginning_of_line, 0, 1, "^p",
-       doc: /* Move point to beginning of current line.
+       doc: /* Move point to beginning of current line (in the logical order).
 With argument N not nil or 1, move forward N - 1 lines first.
 If point reaches the beginning or end of buffer, it stops there.
 
@@ -181,7 +182,7 @@
 }
 
 DEFUN ("end-of-line", Fend_of_line, Send_of_line, 0, 1, "^p",
-       doc: /* Move point to end of current line.
+       doc: /* Move point to end of current line (in the logical order).
 With argument N not nil or 1, move forward N - 1 lines first.
 If point reaches the beginning or end of buffer, it stops there.
 To ignore intangibility, bind `inhibit-point-motion-hooks' to t.